@@ -24,34 +24,25 @@
 
 G_BEGIN_DECLS
 
-typedef enum {
+typedef enum
+{
     FILTER_TYPE_REGEX,
     FILTER_TYPE_FNMATCH
 } FilterType;
 
 
-typedef struct
+struct Filter
 {
-    /* common stuff */
-    FilterType type;
-
-    /* regex filtering stuff */
-    regex_t *re_exp;
-
-    /* fnmatch filtering stuff */
-    char *fn_exp;
-    int fn_flags;
-
-} Filter;
+    FilterType type;    // common stuff
+    regex_t *re_exp;    // regex filtering stuff
+    char *fn_exp;       // fnmatch filtering stuff
+    int fn_flags;       // fnmatch filtering stuff
+};
 
 
-Filter  *filter_new   (const gchar *exp,
-                       gboolean case_sens);
-
-void     filter_free  (Filter *filter);
-
-gboolean filter_match (Filter *filter,
-                       gchar *text);
+Filter  *filter_new (const gchar *exp, gboolean case_sens);
+void filter_free (Filter *filter);
+gboolean filter_match (Filter *filter, gchar *text);
 
 G_END_DECLS
 
