@@ -14,18 +14,21 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __GNOME_CMD_ADVRENAME_LEXER_H__
 #define __GNOME_CMD_ADVRENAME_LEXER_H__
 
-
 #include "gnome-cmd-file.h"
 
+G_BEGIN_DECLS
+
 void gnome_cmd_advrename_reset_counter(unsigned start, unsigned precision, unsigned step);
 void gnome_cmd_advrename_parse_fname(const char *fname);
 char *gnome_cmd_advrename_gen_fname(char *new_fname, size_t new_fname_size, GnomeCmdFile *finfo);
 
 
-#endif //__GNOME_CMD_ADVRENAME_LEXER_H__
+G_END_DECLS
+
+#endif // __GNOME_CMD_ADVRENAME_LEXER_H__
