@@ -1,5 +1,5 @@
 /*
-    GNOME Commander - A GNOME based file manager 
+    GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
@@ -14,20 +14,22 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/ 
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
+
 #ifndef __GNOME_CMD_CHOWN_COMPONENT_H__
 #define __GNOME_CMD_CHOWN_COMPONENT_H__
 
 #include "gnome-cmd-file.h"
 
+G_BEGIN_DECLS
 
 #define GNOME_CMD_CHOWN_COMPONENT(obj) \
-	GTK_CHECK_CAST (obj, gnome_cmd_chown_component_get_type (), GnomeCmdChownComponent)
+    GTK_CHECK_CAST (obj, gnome_cmd_chown_component_get_type (), GnomeCmdChownComponent)
 #define GNOME_CMD_CHOWN_COMPONENT_CLASS(klass) \
-	GTK_CHECK_CLASS_CAST (klass, gnome_cmd_chown_component_get_type (), GnomeCmdChownComponentClass)
+    GTK_CHECK_CLASS_CAST (klass, gnome_cmd_chown_component_get_type (), GnomeCmdChownComponentClass)
 #define GNOME_CMD_IS_CHOWN_COMPONENT(obj) \
-	GTK_CHECK_TYPE (obj, gnome_cmd_chown_component_get_type ())
+    GTK_CHECK_TYPE (obj, gnome_cmd_chown_component_get_type ())
 
 
 typedef struct _GnomeCmdChownComponent GnomeCmdChownComponent;
@@ -35,17 +37,16 @@ typedef struct _GnomeCmdChownComponentPrivate GnomeCmdChownComponentPrivate;
 typedef struct _GnomeCmdChownComponentClass GnomeCmdChownComponentClass;
 
 
-
 struct _GnomeCmdChownComponent
 {
-	GtkTable parent;
-	GnomeCmdChownComponentPrivate *priv;
+    GtkTable parent;
+    GnomeCmdChownComponentPrivate *priv;
 };
 
 
 struct _GnomeCmdChownComponentClass
 {
-	GtkTableClass parent_class;
+    GtkTableClass parent_class;
 };
 
 
@@ -64,9 +65,6 @@ gnome_cmd_chown_component_get_owner (GnomeCmdChownComponent *component);
 gid_t
 gnome_cmd_chown_component_get_group (GnomeCmdChownComponent *component);
 
+G_END_DECLS
 
-
-
-#endif //__GNOME_CMD_CHOWN_COMPONENT_H__
-
-
+#endif // __GNOME_CMD_CHOWN_COMPONENT_H__
