@@ -14,11 +14,13 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
+
 #ifndef __GNOME_CMD_CHOWN_DIALOG_H__
 #define __GNOME_CMD_CHOWN_DIALOG_H__
 
+G_BEGIN_DECLS
 
 #define GNOME_CMD_CHOWN_DIALOG(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_chown_dialog_get_type (), GnomeCmdChownDialog)
@@ -53,9 +55,6 @@ gnome_cmd_chown_dialog_new (GList *files);
 GtkType
 gnome_cmd_chown_dialog_get_type (void);
 
+G_END_DECLS
 
-
-
-#endif //__GNOME_CMD_CHOWN_DIALOG_H__
-
-
+#endif // __GNOME_CMD_CHOWN_DIALOG_H__
