@@ -14,13 +14,15 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #ifndef __GNOME_CMD_CON_SMB_H__
 #define __GNOME_CMD_CON_SMB_H__
 
 #include "gnome-cmd-con.h"
 
+G_BEGIN_DECLS
+
 #define GNOME_CMD_CON_SMB(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_con_smb_get_type (), GnomeCmdConSmb)
 #define GNOME_CMD_CON_SMB_CLASS(klass) \
@@ -53,5 +55,6 @@ gnome_cmd_con_smb_get_type (void);
 GnomeCmdCon *
 gnome_cmd_con_smb_new (void);
 
+G_END_DECLS
 
-#endif //__GNOME_CMD_CON_SMB_H__
+#endif // __GNOME_CMD_CON_SMB_H__
