@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #ifndef __GNOME_CMD_DIR_INDICATOR_H__
 #define __GNOME_CMD_DIR_INDICATOR_H__
@@ -24,6 +24,7 @@
 #include "gnome-cmd-con-device.h"
 #include "gnome-cmd-file-selector.h"
 
+G_BEGIN_DECLS
 
 #define GNOME_CMD_DIR_INDICATOR(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_dir_indicator_get_type (), GnomeCmdDirIndicator)
@@ -58,7 +59,7 @@ GtkWidget *
 gnome_cmd_dir_indicator_new (GnomeCmdFileSelector *fs);
 
 void
-gnome_cmd_dir_indicator_set_dir (GnomeCmdDirIndicator *indicator, const gchar *path);
+gnome_cmd_dir_indicator_set_dir (GnomeCmdDirIndicator *indicator, gchar *path);
 
 void
 gnome_cmd_dir_indicator_set_active (GnomeCmdDirIndicator *indicator, gboolean value);
@@ -69,4 +70,6 @@ gnome_cmd_dir_indicator_show_history (GnomeCmdDirIndicator *indicator);
 void
 gnome_cmd_dir_indicator_show_bookmarks (GnomeCmdDirIndicator *indicator);
 
-#endif //__GNOME_CMD_DIR_INDICATOR_H__
+G_END_DECLS
+
+#endif // __GNOME_CMD_DIR_INDICATOR_H__
