@@ -36,13 +36,16 @@ typedef void (* DirListDoneFunc) (GnomeCmdDir *dir,
                                   GList *files,
                                   GnomeVFSResult result);
 
+#include <string>
+
 #include "gnome-cmd-file.h"
 #include "gnome-cmd-con.h"
 #include "handle.h"
 
 G_BEGIN_DECLS
 
-typedef enum {
+typedef enum
+{
     DIR_STATE_EMPTY,
     DIR_STATE_LISTED,
     DIR_STATE_LISTING,
@@ -74,27 +77,18 @@ struct _GnomeCmdDirClass
 {
     GnomeCmdFileClass parent_class;
 
-    void (* file_created)       (GnomeCmdDir *dir,
-                                 GnomeCmdFile *file);
-    void (* file_deleted)       (GnomeCmdDir *dir,
-                                 GnomeCmdFile *file);
-    void (* file_changed)       (GnomeCmdDir *dir,
-                                 GnomeCmdFile *file);
-    void (* list_ok)            (GnomeCmdDir *dir,
-                                 GList *files);
-    void (* list_failed)        (GnomeCmdDir *dir,
-                                 GnomeVFSResult result);
+    void (* file_created)       (GnomeCmdDir *dir, GnomeCmdFile *file);
+    void (* file_deleted)       (GnomeCmdDir *dir, GnomeCmdFile *file);
+    void (* file_changed)       (GnomeCmdDir *dir, GnomeCmdFile *file);
+    void (* list_ok)            (GnomeCmdDir *dir, GList *files);
+    void (* list_failed)        (GnomeCmdDir *dir, GnomeVFSResult result);
 };
 
 GtkType gnome_cmd_dir_get_type (void);
 
-GnomeCmdDir *gnome_cmd_dir_new_from_info (GnomeVFSFileInfo *info,
-                                          GnomeCmdDir *parent);
-GnomeCmdDir *gnome_cmd_dir_new_with_con (GnomeVFSFileInfo *info,
-                                         GnomeCmdPath *path,
-                                         GnomeCmdCon *con);
-GnomeCmdDir *gnome_cmd_dir_new (GnomeCmdCon *con,
-                                GnomeCmdPath *path);
+GnomeCmdDir *gnome_cmd_dir_new_from_info (GnomeVFSFileInfo *info, GnomeCmdDir *parent);
+GnomeCmdDir *gnome_cmd_dir_new_with_con (GnomeVFSFileInfo *info, GnomeCmdPath *path, GnomeCmdCon *con);
+GnomeCmdDir *gnome_cmd_dir_new (GnomeCmdCon *con, GnomeCmdPath *path);
 GnomeCmdDir *gnome_cmd_dir_get_parent (GnomeCmdDir *dir);
 GnomeCmdDir *gnome_cmd_dir_get_child (GnomeCmdDir *dir, const gchar *child);
 GnomeCmdCon *gnome_cmd_dir_get_connection (GnomeCmdDir *dir);
@@ -113,15 +107,20 @@ void gnome_cmd_dir_set_path (GnomeCmdDir *dir, GnomeCmdPath *path);
 void gnome_cmd_dir_update_path (GnomeCmdDir *dir);
 gchar *gnome_cmd_dir_get_display_path (GnomeCmdDir *dir);
 
+GnomeVFSURI *gnome_cmd_dir_get_uri (GnomeCmdDir *dir);
+gchar       *gnome_cmd_dir_get_uri_str (GnomeCmdDir *dir);
+
 GnomeVFSURI *gnome_cmd_dir_get_child_uri (GnomeCmdDir *dir, const gchar *filename);
 gchar       *gnome_cmd_dir_get_child_uri_str (GnomeCmdDir *dir, const gchar *filename);
 
+GnomeVFSURI *gnome_cmd_dir_get_absolute_path_uri (GnomeCmdDir *dir, std::string &filename);
+
 void gnome_cmd_dir_file_created (GnomeCmdDir *dir, const gchar *filename);
 void gnome_cmd_dir_file_deleted (GnomeCmdDir *dir, const gchar *filename);
 void gnome_cmd_dir_file_changed (GnomeCmdDir *dir, const gchar *filename);
 void gnome_cmd_dir_file_renamed (GnomeCmdDir *dir, GnomeCmdFile *finfo);
-
 gboolean gnome_cmd_dir_uses_fam (GnomeCmdDir *dir);
+
 void gnome_cmd_dir_start_monitoring (GnomeCmdDir *dir);
 void gnome_cmd_dir_cancel_monitoring (GnomeCmdDir *dir);
 gboolean gnome_cmd_dir_is_local (GnomeCmdDir *dir);
