@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #ifndef __GNOME_CMD_PREPARE_XFER_DIALOG_H__
 #define __GNOME_CMD_PREPARE_XFER_DIALOG_H__
@@ -23,6 +23,8 @@
 #include "gnome-cmd-file-list.h"
 #include "gnome-cmd-file-selector.h"
 
+G_BEGIN_DECLS
+
 #define GNOME_CMD_PREPARE_XFER_DIALOG(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_prepare_xfer_dialog_get_type (), GnomeCmdPrepareXferDialog)
 #define GNOME_CMD_PREPARE_XFER_DIALOG_CLASS(klass) \
@@ -71,8 +73,6 @@ gnome_cmd_prepare_xfer_dialog_new (GnomeCmdFileSelector *from,
 GtkType
 gnome_cmd_prepare_xfer_dialog_get_type (void);
 
+G_END_DECLS
 
-
-#endif //__GNOME_CMD_PREPARE_XFER_DIALOG_H__
-
-
+#endif // __GNOME_CMD_PREPARE_XFER_DIALOG_H__
