@@ -14,11 +14,13 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
+
 #ifndef __GNOME_CMD_SMB_NET_H__
 #define __GNOME_CMD_SMB_NET_H__
 
+G_BEGIN_DECLS
 
 typedef enum
 {
@@ -38,10 +40,8 @@ typedef struct
 
 
 
-SmbEntity *
-gnome_cmd_smb_net_get_entity (const gchar *name);
-
-
-#endif //__GNOME_CMD_SMB_NET_H__
+SmbEntity *gnome_cmd_smb_net_get_entity (const gchar *name);
 
+G_END_DECLS
 
+#endif // __GNOME_CMD_SMB_NET_H__
