@@ -14,12 +14,14 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __HISTORY_H__
 #define __HISTORY_H__
 
+G_BEGIN_DECLS
+
 typedef struct
 {
     GList *ents;
@@ -42,4 +44,6 @@ const gchar   *history_back (History *history);
 const gchar   *history_forward (History *history);
 const gchar   *history_last (History *history);
 
-#endif //__HISTORY_H__
+G_END_DECLS
+
+#endif // __HISTORY_H__
