@@ -14,15 +14,27 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __WIDGET_FACTORY_H__
 #define __WIDGET_FACTORY_H__
 
+#include "libgcmd/libgcmd-deps.h"
+#include "gnome-cmd-combo.h"
 
-GtkWidget *
-create_clist_combo (GtkWidget *parent, gint num_cols, gint text_col, gchar **titles);
+G_BEGIN_DECLS
 
+inline GtkWidget *create_clist_combo (GtkWidget *parent, gint num_cols, gint text_col, gchar **titles)
+{
+    GtkWidget *combo = gnome_cmd_combo_new (num_cols, text_col, titles);
+    gtk_widget_ref (combo);
+    gtk_object_set_data_full (GTK_OBJECT (parent), "combo", combo, (GtkDestroyNotify) gtk_widget_unref);
+    gtk_widget_show (combo);
 
-#endif //__WIDGET_FACTORY_H__
+    return combo;
+}
+
+G_END_DECLS
+
+#endif // __WIDGET_FACTORY_H__
