@@ -14,7 +14,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
    Author: Assaf Gordon  <agordon88@gmail.com>
 */
@@ -31,25 +31,25 @@
 #include <libgviewer/libgviewer.h>
 #include <libgnomeui/libgnomeui.h>
 
+
 static void destroy(GObject *a, gpointer data)
 {
     g_warning("destroy");
     gtk_main_quit();
 }
 
-int main(int argc, char* argv[])
-{
-    GtkWidget *w ;
 
-    gnome_init("gnome-commander","0.1",argc,argv);
-    
-    w = gviewer_window_file_view(argv[1],NULL);
-    
-    gtk_widget_show(w);
-    
-    g_signal_connect(G_OBJECT(w),"delete-event",G_CALLBACK(destroy),NULL);
-    
-    gtk_main();
+int main(int argc, char *argv[])
+{
+    gnome_init ("gnome-commander", "0.1", argc, argv);
+
+    GtkWidget *w = gviewer_window_file_view (argv[1], NULL);
+
+    gtk_widget_show (w);
+
+    g_signal_connect(G_OBJECT(w), "delete-event", G_CALLBACK(destroy), NULL);
+
+    gtk_main ();
 
     return 0;
 }
